class Thermostat
  attr_accessor :unit, :current_temp, :wanted_temp, :range

  # Sets the unit value
  def unit_set(unit)
    @unit = unit
  end

  # @return [Integer] returns the range (converted to fahrenheit if necessary)
  def range_set(range)
    @range = if @unit == 'fahrenheit'
               (range * 0.5555555) / 2 # 5/9 won't work so I take 0.5555555
             else
               range / 2
             end
  end

  # @return [Integer] returns the wanted temperature (converted to fahrenheit or kelvin if necessary)
  def wanted_temp_set(wanted_temp)
    @wanted_temp = if @unit == 'fahrenheit'
                     (wanted_temp - 32) / 1.8 # 9/5 won't work so I take 1.8
                   elsif @unit == 'kelvin'
                     (wanted_temp - 273.15)
                   else
                     wanted_temp
                   end
  end

  # @return [Integer] returns the current temperature (converted to fahrenheit or kelvin if necessary)
  def update_temp(current_temp)
    @current_temp = if @unit == 'fahrenheit'
                      (current_temp - 32) / 1.8 # 9/5 won't work so I take 1.8
                    elsif @unit == 'kelvin'
                      (current_temp - 273.15)
                    else
                      current_temp
                    end
  end

  # @return [JSON] returns the JSON-output
  def output
    if (@wanted_temp + @range) < @current_temp
      JSON.generate(cooling: true, heating: false)
    elsif (@wanted_temp - @range) > @current_temp
      JSON.generate(cooling: false, heating: true)
    elsif ((@wanted_temp - @range) <= @current_temp) &&
          ((@wanted_temp + @range) >= @current_temp)
      JSON.generate(cooling: false, heating: false)
    end
  end
end
